=======
History
=======

1.2.0 (2022-02-25)
------------------

* Add ``django_rich.test.RichRunner``, a custom test runner that uses Rich colouring and tracebacks.

  Thanks to David Smith in `PR #29 <https://github.com/adamchainz/django-rich/pull/29>`__.

1.1.0 (2022-01-10)
------------------

* Drop Python 3.6 support.

1.0.0 (2021-11-25)
------------------

* First version.
